@@ -21,8 +21,10 @@ from google.cloud.bigquery_connection_v1.services.connection_service.async_clien
     ConnectionServiceAsyncClient,
 )
 
+from google.cloud.bigquery_connection_v1.types.connection import AwsAccessRole
 from google.cloud.bigquery_connection_v1.types.connection import AwsCrossAccountRole
 from google.cloud.bigquery_connection_v1.types.connection import AwsProperties
+from google.cloud.bigquery_connection_v1.types.connection import CloudSpannerProperties
 from google.cloud.bigquery_connection_v1.types.connection import CloudSqlCredential
 from google.cloud.bigquery_connection_v1.types.connection import CloudSqlProperties
 from google.cloud.bigquery_connection_v1.types.connection import Connection
@@ -36,8 +38,10 @@ from google.cloud.bigquery_connection_v1.types.connection import UpdateConnectio
 __all__ = (
     "ConnectionServiceClient",
     "ConnectionServiceAsyncClient",
+    "AwsAccessRole",
     "AwsCrossAccountRole",
     "AwsProperties",
+    "CloudSpannerProperties",
     "CloudSqlCredential",
     "CloudSqlProperties",
     "Connection",
